@@ -75,7 +75,7 @@ def delete_test_db():
     from sqlalchemy import create_engine
     from stratus_api.core.settings import get_settings
     assert get_settings()['environment'] == 'test' and get_settings()['prefix']
-    create_engine(__db_url__).dispose()
+    __connection__.dispose()
     default_db = create_engine(__default_db_url__)
 
     with default_db.connect() as conn:
